@@ -1,15 +1,13 @@
-from typing import Dict, Iterable, List, Optional, Tuple
+from typing import Any, Dict, Iterable, Optional, Tuple, Type, Union
 
 import attr
 from attr.validators import deep_iterable, deep_mapping, in_, instance_of, optional
-
 from markdown_it import MarkdownIt
 from markdown_it.renderer import RendererHTML
-
 from mdit_py_plugins.amsmath import amsmath_plugin
 from mdit_py_plugins.anchors import anchors_plugin
-from mdit_py_plugins.deflist import deflist_plugin
 from mdit_py_plugins.colon_fence import colon_fence_plugin
+from mdit_py_plugins.deflist import deflist_plugin
 from mdit_py_plugins.dollarmath import dollarmath_plugin
 from mdit_py_plugins.footnote import footnote_plugin
 from mdit_py_plugins.front_matter import front_matter_plugin
@@ -69,6 +67,7 @@ class MdParserConfig:
                 "dollarmath",
                 "amsmath",
                 "deflist",
+                "html_admonition",
                 "html_image",
                 "colon_fence",
                 "smartquotes",
@@ -80,13 +79,13 @@ class MdParserConfig:
         if diff:
             raise ValueError(f"myst_enable_extensions not recognised: {diff}")
 
-    disable_syntax: List[str] = attr.ib(
+    disable_syntax: Iterable[str] = attr.ib(
         factory=list,
         validator=deep_iterable(instance_of(str), instance_of((list, tuple))),
     )
 
     # see https://en.wikipedia.org/wiki/List_of_URI_schemes
-    url_schemes: Optional[List[str]] = attr.ib(
+    url_schemes: Optional[Iterable[str]] = attr.ib(
         default=None,
         validator=optional(deep_iterable(instance_of(str), instance_of((list, tuple)))),
     )
@@ -95,9 +94,20 @@ class MdParserConfig:
         default=None, validator=optional(in_([1, 2, 3, 4, 5, 6, 7]))
     )
 
-    substitutions: Dict[str, str] = attr.ib(
+    html_meta: Dict[str, str] = attr.ib(
         factory=dict,
         validator=deep_mapping(instance_of(str), instance_of(str), instance_of(dict)),
+        repr=lambda v: str(list(v)),
+    )
+
+    footnote_transition: bool = attr.ib(default=True, validator=instance_of(bool))
+
+    substitutions: Dict[str, Union[str, int, float]] = attr.ib(
+        factory=dict,
+        validator=deep_mapping(
+            instance_of(str), instance_of((str, int, float)), instance_of(dict)
+        ),
+        repr=lambda v: str(list(v)),
     )
 
     sub_delimiters: Tuple[str, str] = attr.ib(default=("{", "}"))
@@ -118,6 +128,8 @@ class MdParserConfig:
 
 def default_parser(config: MdParserConfig) -> MarkdownIt:
     """Return the default parser configuration for MyST"""
+    renderer_cls: Type[Any]  # TODO no abstract render class
+
     if config.renderer == "sphinx":
         from myst_parser.sphinx_renderer import SphinxRenderer
 
@@ -181,13 +193,19 @@ def default_parser(config: MdParserConfig) -> MarkdownIt:
 
     md.options.update(
         {
-            "commonmark_only": False,
+            # standard options
             "typographer": typographer,
             "linkify": "linkify" in config.enable_extensions,
-            "enable_html_img": "html_image" in config.enable_extensions,
+            # myst options
+            "commonmark_only": False,
+            "myst_extensions": set(
+                list(config.enable_extensions)
+                + (["heading_anchors"] if config.heading_anchors is not None else [])
+            ),
             "myst_url_schemes": config.url_schemes,
-            "enable_anchors": config.heading_anchors is not None,
-            "substitutions": config.substitutions,
+            "myst_substitutions": config.substitutions,
+            "myst_html_meta": config.html_meta,
+            "myst_footnote_transition": config.footnote_transition,
         }
     )
 
@@ -204,7 +222,7 @@ def to_docutils(
     conf=None,
     srcdir=None,
 ):
-    """Render text to the docutils AST
+    """Render text to the docutils AST (before transforms)
 
     :param text: the text to render
     :param options: options to update the parser with
@@ -213,7 +231,7 @@ def to_docutils(
     :param document: the docutils root node to use (otherwise a new one will be created)
     :param in_sphinx_env: initialise a minimal sphinx environment (useful for testing)
     :param conf: the sphinx conf.py as a dictionary
-    :param srcdir: to parse to the mock sphinc env
+    :param srcdir: to parse to the mock sphinx env
 
     :returns: docutils document
     """
